# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: vega/snapshot/v1/snapshot.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database

# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ... import vega_pb2 as vega_dot_vega__pb2
from ... import markets_pb2 as vega_dot_markets__pb2
from ... import assets_pb2 as vega_dot_assets__pb2
from ... import chain_events_pb2 as vega_dot_chain__events__pb2
from ... import governance_pb2 as vega_dot_governance__pb2
from ...events.v1 import events_pb2 as vega_dot_events_dot_v1_dot_events__pb2
from ...checkpoint.v1 import (
    checkpoint_pb2 as vega_dot_checkpoint_dot_v1_dot_checkpoint__pb2,
)
from ...data.v1 import data_pb2 as vega_dot_data_dot_v1_dot_data__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n\x1fvega/snapshot/v1/snapshot.proto\x12\x10vega.snapshot.v1\x1a\x0fvega/vega.proto\x1a\x12vega/markets.proto\x1a\x11vega/assets.proto\x1a\x17vega/chain_events.proto\x1a\x15vega/governance.proto\x1a\x1bvega/events/v1/events.proto\x1a#vega/checkpoint/v1/checkpoint.proto\x1a\x17vega/data/v1/data.proto"\x9c\x01\n\x08Snapshot\x12\x16\n\x06height\x18\x01 \x01(\x04R\x06height\x12\x30\n\x06\x66ormat\x18\x02 \x01(\x0e\x32\x18.vega.snapshot.v1.FormatR\x06\x66ormat\x12\x16\n\x06\x63hunks\x18\x03 \x01(\rR\x06\x63hunks\x12\x12\n\x04hash\x18\x04 \x01(\x0cR\x04hash\x12\x1a\n\x08metadata\x18\x05 \x01(\x0cR\x08metadata"{\n\x08NodeHash\x12\x10\n\x03key\x18\x03 \x01(\tR\x03key\x12\x12\n\x04hash\x18\x04 \x01(\tR\x04hash\x12\x16\n\x06height\x18\x05 \x01(\x05R\x06height\x12\x18\n\x07version\x18\x06 \x01(\x03R\x07version\x12\x17\n\x07is_leaf\x18\x07 \x01(\x08R\x06isLeaf"\x84\x01\n\x08Metadata\x12\x18\n\x07version\x18\x01 \x01(\x03R\x07version\x12!\n\x0c\x63hunk_hashes\x18\x02 \x03(\tR\x0b\x63hunkHashes\x12;\n\x0bnode_hashes\x18\x03 \x03(\x0b\x32\x1a.vega.snapshot.v1.NodeHashR\nnodeHashes"V\n\x05\x43hunk\x12-\n\x04\x64\x61ta\x18\x01 \x03(\x0b\x32\x19.vega.snapshot.v1.PayloadR\x04\x64\x61ta\x12\x0e\n\x02nr\x18\x02 \x01(\x03R\x02nr\x12\x0e\n\x02of\x18\x03 \x01(\x03R\x02of"\xab"\n\x07Payload\x12\x45\n\ractive_assets\x18\x01 \x01(\x0b\x32\x1e.vega.snapshot.v1.ActiveAssetsH\x00R\x0c\x61\x63tiveAssets\x12H\n\x0epending_assets\x18\x02 \x01(\x0b\x32\x1f.vega.snapshot.v1.PendingAssetsH\x00R\rpendingAssets\x12W\n\x13\x62\x61nking_withdrawals\x18\x03 \x01(\x0b\x32$.vega.snapshot.v1.BankingWithdrawalsH\x00R\x12\x62\x61nkingWithdrawals\x12N\n\x10\x62\x61nking_deposits\x18\x04 \x01(\x0b\x32!.vega.snapshot.v1.BankingDepositsH\x00R\x0f\x62\x61nkingDeposits\x12\x42\n\x0c\x62\x61nking_seen\x18\x05 \x01(\x0b\x32\x1d.vega.snapshot.v1.BankingSeenH\x00R\x0b\x62\x61nkingSeen\x12[\n\x15\x62\x61nking_asset_actions\x18\x06 \x01(\x0b\x32%.vega.snapshot.v1.BankingAssetActionsH\x00R\x13\x62\x61nkingAssetActions\x12>\n\ncheckpoint\x18\x07 \x01(\x0b\x32\x1c.vega.snapshot.v1.CheckpointH\x00R\ncheckpoint\x12W\n\x13\x63ollateral_accounts\x18\x08 \x01(\x0b\x32$.vega.snapshot.v1.CollateralAccountsH\x00R\x12\x63ollateralAccounts\x12Q\n\x11\x63ollateral_assets\x18\t \x01(\x0b\x32".vega.snapshot.v1.CollateralAssetsH\x00R\x10\x63ollateralAssets\x12Q\n\x11\x64\x65legation_active\x18\n \x01(\x0b\x32".vega.snapshot.v1.DelegationActiveH\x00R\x10\x64\x65legationActive\x12T\n\x12\x64\x65legation_pending\x18\x0b \x01(\x0b\x32#.vega.snapshot.v1.DelegationPendingH\x00R\x11\x64\x65legationPending\x12K\n\x0f\x64\x65legation_auto\x18\x0c \x01(\x0b\x32 .vega.snapshot.v1.DelegationAutoH\x00R\x0e\x64\x65legationAuto\x12Q\n\x11governance_active\x18\r \x01(\x0b\x32".vega.snapshot.v1.GovernanceActiveH\x00R\x10governanceActive\x12T\n\x12governance_enacted\x18\x0e \x01(\x0b\x32#.vega.snapshot.v1.GovernanceEnactedH\x00R\x11governanceEnacted\x12N\n\x10staking_accounts\x18\x0f \x01(\x0b\x32!.vega.snapshot.v1.StakingAccountsH\x00R\x0fstakingAccounts\x12\x45\n\rmatching_book\x18\x10 \x01(\x0b\x32\x1e.vega.snapshot.v1.MatchingBookH\x00R\x0cmatchingBook\x12L\n\x12network_parameters\x18\x11 \x01(\x0b\x32\x1b.vega.snapshot.v1.NetParamsH\x00R\x11networkParameters\x12Q\n\x11\x65xecution_markets\x18\x12 \x01(\x0b\x32".vega.snapshot.v1.ExecutionMarketsH\x00R\x10\x65xecutionMarkets\x12N\n\x10market_positions\x18\x13 \x01(\x0b\x32!.vega.snapshot.v1.MarketPositionsH\x00R\x0fmarketPositions\x12\x39\n\tapp_state\x18\x14 \x01(\x0b\x32\x1a.vega.snapshot.v1.AppStateH\x00R\x08\x61ppState\x12\x34\n\x05\x65poch\x18\x15 \x01(\x0b\x32\x1c.vega.snapshot.v1.EpochStateH\x00R\x05\x65poch\x12\x61\n\x17rewards_pending_payouts\x18\x17 \x01(\x0b\x32\'.vega.snapshot.v1.RewardsPendingPayoutsH\x00R\x15rewardsPendingPayouts\x12K\n\x0fgovernance_node\x18\x18 \x01(\x0b\x32 .vega.snapshot.v1.GovernanceNodeH\x00R\x0egovernanceNode\x12?\n\x0blimit_state\x18\x19 \x01(\x0b\x32\x1c.vega.snapshot.v1.LimitStateH\x00R\nlimitState\x12L\n\x10vote_spam_policy\x18\x1a \x01(\x0b\x32 .vega.snapshot.v1.VoteSpamPolicyH\x00R\x0evoteSpamPolicy\x12R\n\x12simple_spam_policy\x18\x1b \x01(\x0b\x32".vega.snapshot.v1.SimpleSpamPolicyH\x00R\x10simpleSpamPolicy\x12\x32\n\x06notary\x18\x1c \x01(\x0b\x32\x18.vega.snapshot.v1.NotaryH\x00R\x06notary\x12K\n\x0f\x65vent_forwarder\x18\x1f \x01(\x0b\x32 .vega.snapshot.v1.EventForwarderH\x00R\x0e\x65ventForwarder\x12\x64\n\x18stake_verifier_deposited\x18  \x01(\x0b\x32(.vega.snapshot.v1.StakeVerifierDepositedH\x00R\x16stakeVerifierDeposited\x12^\n\x16stake_verifier_removed\x18! \x01(\x0b\x32&.vega.snapshot.v1.StakeVerifierRemovedH\x00R\x14stakeVerifierRemoved\x12\x35\n\x07witness\x18" \x01(\x0b\x32\x19.vega.snapshot.v1.WitnessH\x00R\x07witness\x12\x83\x01\n#delegation_last_reconciliation_time\x18# \x01(\x0b\x32\x32.vega.snapshot.v1.DelegationLastReconciliationTimeH\x00R delegationLastReconciliationTime\x12\x38\n\x08topology\x18$ \x01(\x0b\x32\x1a.vega.snapshot.v1.TopologyH\x00R\x08topology\x12\x44\n\x0boracle_data\x18% \x01(\x0b\x32!.vega.snapshot.v1.OracleDataBatchH\x00R\noracleData\x12Z\n\x14liquidity_parameters\x18& \x01(\x0b\x32%.vega.snapshot.v1.LiquidityParametersH\x00R\x13liquidityParameters\x12p\n\x1cliquidity_pending_provisions\x18\' \x01(\x0b\x32,.vega.snapshot.v1.LiquidityPendingProvisionsH\x00R\x1aliquidityPendingProvisions\x12\x80\x01\n"liquidity_parties_liquidity_orders\x18( \x01(\x0b\x32\x31.vega.snapshot.v1.LiquidityPartiesLiquidityOrdersH\x00R\x1fliquidityPartiesLiquidityOrders\x12\x64\n\x18liquidity_parties_orders\x18) \x01(\x0b\x32(.vega.snapshot.v1.LiquidityPartiesOrdersH\x00R\x16liquidityPartiesOrders\x12Z\n\x14liquidity_provisions\x18* \x01(\x0b\x32%.vega.snapshot.v1.LiquidityProvisionsH\x00R\x13liquidityProvisions\x12T\n\x12liquidity_supplied\x18+ \x01(\x0b\x32#.vega.snapshot.v1.LiquiditySuppliedH\x00R\x11liquiditySupplied\x12N\n\x10liquidity_target\x18, \x01(\x0b\x32!.vega.snapshot.v1.LiquidityTargetH\x00R\x0fliquidityTarget\x12\x64\n\x18\x66loating_point_consensus\x18. \x01(\x0b\x32(.vega.snapshot.v1.FloatingPointConsensusH\x00R\x16\x66loatingPointConsensus\x12H\n\x0emarket_tracker\x18/ \x01(\x0b\x32\x1f.vega.snapshot.v1.MarketTrackerH\x00R\rmarketTracker\x12m\n\x1b\x62\x61nking_recurring_transfers\x18\x31 \x01(\x0b\x32+.vega.snapshot.v1.BankingRecurringTransfersH\x00R\x19\x62\x61nkingRecurringTransfers\x12m\n\x1b\x62\x61nking_scheduled_transfers\x18\x32 \x01(\x0b\x32+.vega.snapshot.v1.BankingScheduledTransfersH\x00R\x19\x62\x61nkingScheduledTransfers\x12z\n erc20_multisig_topology_verified\x18\x33 \x01(\x0b\x32/.vega.snapshot.v1.ERC20MultiSigTopologyVerifiedH\x00R\x1d\x65rc20MultisigTopologyVerified\x12w\n\x1f\x65rc20_multisig_topology_pending\x18\x34 \x01(\x0b\x32..vega.snapshot.v1.ERC20MultiSigTopologyPendingH\x00R\x1c\x65rc20MultisigTopologyPending\x12\x43\n\rproof_of_work\x18\x35 \x01(\x0b\x32\x1d.vega.snapshot.v1.ProofOfWorkH\x00R\x0bproofOfWork\x12[\n\x15pending_asset_updates\x18\x36 \x01(\x0b\x32%.vega.snapshot.v1.PendingAssetUpdatesH\x00R\x13pendingAssetUpdates\x12j\n\x1aprotocol_upgrade_proposals\x18\x37 \x01(\x0b\x32*.vega.snapshot.v1.ProtocolUpgradeProposalsH\x00R\x18protocolUpgradeProposals\x12X\n\x14\x62\x61nking_bridge_state\x18\x38 \x01(\x0b\x32$.vega.snapshot.v1.BankingBridgeStateH\x00R\x12\x62\x61nkingBridgeStateB\x06\n\x04\x64\x61ta"R\n\x17TimestampedOpenInterest\x12#\n\ropen_interest\x18\x01 \x01(\x04R\x0copenInterest\x12\x12\n\x04time\x18\x02 \x01(\x03R\x04time"\xf2\x02\n\x0fLiquidityTarget\x12\x1b\n\tmarket_id\x18\x01 \x01(\tR\x08marketId\x12!\n\x0c\x63urrent_time\x18\x02 \x01(\x03R\x0b\x63urrentTime\x12-\n\x12scheduled_truncate\x18\x03 \x01(\x03R\x11scheduledTruncate\x12\x34\n\x16\x63urrent_open_interests\x18\x04 \x03(\x04R\x14\x63urrentOpenInterests\x12\x61\n\x17previous_open_interests\x18\x05 \x03(\x0b\x32).vega.snapshot.v1.TimestampedOpenInterestR\x15previousOpenInterests\x12W\n\x12max_open_interests\x18\x06 \x01(\x0b\x32).vega.snapshot.v1.TimestampedOpenInterestR\x10maxOpenInterests"W\n\x1dLiquidityPriceProbabilityPair\x12\x14\n\x05price\x18\x01 \x01(\tR\x05price\x12 \n\x0bprobability\x18\x02 \x01(\tR\x0bprobability"\xf9\x01\n\x11LiquiditySupplied\x12\x1b\n\tmarket_id\x18\x01 \x01(\tR\x08marketId\x12+\n\x11\x63onsensus_reached\x18\x02 \x01(\x08R\x10\x63onsensusReached\x12L\n\tbid_cache\x18\x03 \x03(\x0b\x32/.vega.snapshot.v1.LiquidityPriceProbabilityPairR\x08\x62idCache\x12L\n\task_cache\x18\x04 \x03(\x0b\x32/.vega.snapshot.v1.LiquidityPriceProbabilityPairR\x08\x61skCache"P\n\x0fOracleDataBatch\x12=\n\x0boracle_data\x18\x01 \x03(\x0b\x32\x1c.vega.snapshot.v1.OracleDataR\noracleData"r\n\nOracleData\x12.\n\x07signers\x18\x01 \x03(\x0b\x32\x14.vega.data.v1.SignerR\x07signers\x12\x34\n\x04\x64\x61ta\x18\x02 \x03(\x0b\x32 .vega.snapshot.v1.OracleDataPairR\x04\x64\x61ta"8\n\x0eOracleDataPair\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n\x05value\x18\x02 \x01(\tR\x05value"C\n\x07Witness\x12\x38\n\tresources\x18\x01 \x03(\x0b\x32\x1a.vega.snapshot.v1.ResourceR\tresources"g\n\x08Resource\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\x12\x1f\n\x0b\x63heck_until\x18\x02 \x01(\x03R\ncheckUntil\x12\x14\n\x05votes\x18\x03 \x03(\tR\x05votes\x12\x14\n\x05state\x18\x04 \x01(\rR\x05state"3\n\x0e\x45ventForwarder\x12!\n\x0c\x61\x63ked_events\x18\x01 \x03(\tR\x0b\x61\x63kedEvents"?\n\x12\x43ollateralAccounts\x12)\n\x08\x61\x63\x63ounts\x18\x01 \x03(\x0b\x32\r.vega.AccountR\x08\x61\x63\x63ounts"7\n\x10\x43ollateralAssets\x12#\n\x06\x61ssets\x18\x01 \x03(\x0b\x32\x0b.vega.AssetR\x06\x61ssets"3\n\x0c\x41\x63tiveAssets\x12#\n\x06\x61ssets\x18\x01 \x03(\x0b\x32\x0b.vega.AssetR\x06\x61ssets"4\n\rPendingAssets\x12#\n\x06\x61ssets\x18\x01 \x03(\x0b\x32\x0b.vega.AssetR\x06\x61ssets":\n\x13PendingAssetUpdates\x12#\n\x06\x61ssets\x18\x01 \x03(\x0b\x32\x0b.vega.AssetR\x06\x61ssets"P\n\nWithdrawal\x12\x10\n\x03ref\x18\x01 \x01(\tR\x03ref\x12\x30\n\nwithdrawal\x18\x02 \x01(\x0b\x32\x10.vega.WithdrawalR\nwithdrawal"B\n\x07\x44\x65posit\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\x12\'\n\x07\x64\x65posit\x18\x02 \x01(\x0b\x32\r.vega.DepositR\x07\x64\x65posit"i\n\x05TxRef\x12\x14\n\x05\x61sset\x18\x01 \x01(\tR\x05\x61sset\x12\x19\n\x08\x62lock_nr\x18\x02 \x01(\x04R\x07\x62lockNr\x12\x12\n\x04hash\x18\x03 \x01(\tR\x04hash\x12\x1b\n\tlog_index\x18\x04 \x01(\x04R\x08logIndex"\x8d\x04\n\x0b\x41ssetAction\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\x12\x14\n\x05state\x18\x02 \x01(\rR\x05state\x12\x14\n\x05\x61sset\x18\x03 \x01(\tR\x05\x61sset\x12!\n\x0c\x62lock_number\x18\x04 \x01(\x04R\x0b\x62lockNumber\x12\x19\n\x08tx_index\x18\x05 \x01(\x04R\x07txIndex\x12\x12\n\x04hash\x18\x06 \x01(\tR\x04hash\x12\x42\n\x0f\x62uiltin_deposit\x18\x07 \x01(\x0b\x32\x19.vega.BuiltinAssetDepositR\x0e\x62uiltinDeposit\x12\x37\n\rerc20_deposit\x18\x08 \x01(\x0b\x32\x12.vega.ERC20DepositR\x0c\x65rc20Deposit\x12\x33\n\nasset_list\x18\t \x01(\x0b\x32\x14.vega.ERC20AssetListR\tassetList\x12Z\n\x1a\x65rc20_asset_limits_updated\x18\n \x01(\x0b\x32\x1d.vega.ERC20AssetLimitsUpdatedR\x17\x65rc20AssetLimitsUpdated\x12\x30\n\x14\x65rc20_bridge_stopped\x18\x0b \x01(\x08R\x12\x65rc20BridgeStopped\x12\x30\n\x14\x65rc20_bridge_resumed\x18\x0c \x01(\x08R\x12\x65rc20BridgeResumed"T\n\x12\x42\x61nkingWithdrawals\x12>\n\x0bwithdrawals\x18\x01 \x03(\x0b\x32\x1c.vega.snapshot.v1.WithdrawalR\x0bwithdrawals"F\n\x0f\x42\x61nkingDeposits\x12\x33\n\x07\x64\x65posit\x18\x01 \x03(\x0b\x32\x19.vega.snapshot.v1.DepositR\x07\x64\x65posit"!\n\x0b\x42\x61nkingSeen\x12\x12\n\x04refs\x18\x01 \x03(\tR\x04refs"W\n\x13\x42\x61nkingAssetActions\x12@\n\x0c\x61sset_action\x18\x01 \x03(\x0b\x32\x1d.vega.snapshot.v1.AssetActionR\x0b\x61ssetAction"t\n\x19\x42\x61nkingRecurringTransfers\x12W\n\x13recurring_transfers\x18\x01 \x01(\x0b\x32&.vega.checkpoint.v1.RecurringTransfersR\x12recurringTransfers"t\n\x19\x42\x61nkingScheduledTransfers\x12W\n\x11transfers_at_time\x18\x01 \x03(\x0b\x32+.vega.checkpoint.v1.ScheduledTransferAtTimeR\x0ftransfersAtTime"X\n\x12\x42\x61nkingBridgeState\x12\x42\n\x0c\x62ridge_state\x18\x01 \x01(\x0b\x32\x1f.vega.checkpoint.v1.BridgeStateR\x0b\x62ridgeState"%\n\nCheckpoint\x12\x17\n\x07next_cp\x18\x01 \x01(\x03R\x06nextCp"\\\n DelegationLastReconciliationTime\x12\x38\n\x18last_reconciliation_time\x18\x01 \x01(\x03R\x16lastReconciliationTime"F\n\x10\x44\x65legationActive\x12\x32\n\x0b\x64\x65legations\x18\x01 \x03(\x0b\x32\x10.vega.DelegationR\x0b\x64\x65legations"}\n\x11\x44\x65legationPending\x12\x32\n\x0b\x64\x65legations\x18\x01 \x03(\x0b\x32\x10.vega.DelegationR\x0b\x64\x65legations\x12\x34\n\x0cundelegation\x18\x02 \x03(\x0b\x32\x10.vega.DelegationR\x0cundelegation"*\n\x0e\x44\x65legationAuto\x12\x18\n\x07parties\x18\x01 \x03(\tR\x07parties"\x9a\x01\n\x0cProposalData\x12*\n\x08proposal\x18\x01 \x01(\x0b\x32\x0e.vega.ProposalR\x08proposal\x12\x1c\n\x03yes\x18\x02 \x03(\x0b\x32\n.vega.VoteR\x03yes\x12\x1a\n\x02no\x18\x03 \x03(\x0b\x32\n.vega.VoteR\x02no\x12$\n\x07invalid\x18\x04 \x03(\x0b\x32\n.vega.VoteR\x07invalid"Q\n\x11GovernanceEnacted\x12<\n\tproposals\x18\x01 \x03(\x0b\x32\x1e.vega.snapshot.v1.ProposalDataR\tproposals"P\n\x10GovernanceActive\x12<\n\tproposals\x18\x01 \x03(\x0b\x32\x1e.vega.snapshot.v1.ProposalDataR\tproposals">\n\x0eGovernanceNode\x12,\n\tproposals\x18\x01 \x03(\x0b\x32\x0e.vega.ProposalR\tproposals"v\n\x0eStakingAccount\x12\x14\n\x05party\x18\x01 \x01(\tR\x05party\x12\x18\n\x07\x62\x61lance\x18\x02 \x01(\tR\x07\x62\x61lance\x12\x34\n\x06\x65vents\x18\x03 \x03(\x0b\x32\x1c.vega.events.v1.StakeLinkingR\x06\x65vents"\x8c\x01\n\x0fStakingAccounts\x12<\n\x08\x61\x63\x63ounts\x18\x01 \x03(\x0b\x32 .vega.snapshot.v1.StakingAccountR\x08\x61\x63\x63ounts\x12;\n\x1astaking_asset_total_supply\x18\x02 \x01(\tR\x17stakingAssetTotalSupply"\xcc\x01\n\x0cMatchingBook\x12\x1b\n\tmarket_id\x18\x01 \x01(\tR\x08marketId\x12\x1d\n\x03\x62uy\x18\x02 \x03(\x0b\x32\x0b.vega.OrderR\x03\x62uy\x12\x1f\n\x04sell\x18\x03 \x03(\x0b\x32\x0b.vega.OrderR\x04sell\x12*\n\x11last_traded_price\x18\x04 \x01(\tR\x0flastTradedPrice\x12\x18\n\x07\x61uction\x18\x05 \x01(\x08R\x07\x61uction\x12\x19\n\x08\x62\x61tch_id\x18\x06 \x01(\x04R\x07\x62\x61tchId";\n\tNetParams\x12.\n\x06params\x18\x01 \x03(\x0b\x32\x16.vega.NetworkParameterR\x06params"0\n\nDecimalMap\x12\x10\n\x03key\x18\x01 \x01(\x03R\x03key\x12\x10\n\x03val\x18\x02 \x01(\tR\x03val"5\n\tTimePrice\x12\x12\n\x04time\x18\x01 \x01(\x03R\x04time\x12\x14\n\x05price\x18\x02 \x01(\tR\x05price";\n\x0bPriceVolume\x12\x14\n\x05price\x18\x01 \x01(\tR\x05price\x12\x16\n\x06volume\x18\x02 \x01(\x04R\x06volume"B\n\nPriceRange\x12\x10\n\x03min\x18\x01 \x01(\tR\x03min\x12\x10\n\x03max\x18\x02 \x01(\tR\x03max\x12\x10\n\x03ref\x18\x03 \x01(\tR\x03ref"\x9a\x01\n\nPriceBound\x12\x16\n\x06\x61\x63tive\x18\x01 \x01(\x08R\x06\x61\x63tive\x12\x1b\n\tup_factor\x18\x02 \x01(\tR\x08upFactor\x12\x1f\n\x0b\x64own_factor\x18\x03 \x01(\tR\ndownFactor\x12\x36\n\x07trigger\x18\x04 \x01(\x0b\x32\x1c.vega.PriceMonitoringTriggerR\x07trigger"y\n\x0fPriceRangeCache\x12\x32\n\x05\x62ound\x18\x01 \x01(\x0b\x32\x1c.vega.snapshot.v1.PriceBoundR\x05\x62ound\x12\x32\n\x05range\x18\x02 \x01(\x0b\x32\x1c.vega.snapshot.v1.PriceRangeR\x05range"<\n\x0c\x43urrentPrice\x12\x14\n\x05price\x18\x01 \x01(\tR\x05price\x12\x16\n\x06volume\x18\x02 \x01(\x04R\x06volume"S\n\tPastPrice\x12\x12\n\x04time\x18\x01 \x01(\x03R\x04time\x12\x32\n\x15volume_weighted_price\x18\x02 \x01(\tR\x13volumeWeightedPrice"\xf4\x04\n\x0cPriceMonitor\x12 \n\x0binitialised\x18\x03 \x01(\x08R\x0binitialised\x12=\n\x0b\x66p_horizons\x18\x04 \x03(\x0b\x32\x1c.vega.snapshot.v1.DecimalMapR\nfpHorizons\x12\x10\n\x03now\x18\x05 \x01(\x03R\x03now\x12\x16\n\x06update\x18\x06 \x01(\x03R\x06update\x12\x34\n\x06\x62ounds\x18\x07 \x03(\x0b\x32\x1c.vega.snapshot.v1.PriceBoundR\x06\x62ounds\x12\x33\n\x16price_range_cache_time\x18\x08 \x01(\x03R\x13priceRangeCacheTime\x12M\n\x11price_range_cache\x18\t \x03(\x0b\x32!.vega.snapshot.v1.PriceRangeCacheR\x0fpriceRangeCache\x12/\n\x14ref_price_cache_time\x18\n \x01(\x03R\x11refPriceCacheTime\x12\x44\n\x0fref_price_cache\x18\x0b \x03(\x0b\x32\x1c.vega.snapshot.v1.DecimalMapR\rrefPriceCache\x12=\n\nprices_now\x18\x0c \x03(\x0b\x32\x1e.vega.snapshot.v1.CurrentPriceR\tpricesNow\x12<\n\x0bprices_past\x18\r \x03(\x0b\x32\x1b.vega.snapshot.v1.PastPriceR\npricesPast\x12+\n\x11\x63onsensus_reached\x18\x0e \x01(\x08R\x10\x63onsensusReached"\xf8\x02\n\x0c\x41uctionState\x12,\n\x04mode\x18\x01 \x01(\x0e\x32\x18.vega.Market.TradingModeR\x04mode\x12;\n\x0c\x64\x65\x66\x61ult_mode\x18\x02 \x01(\x0e\x32\x18.vega.Market.TradingModeR\x0b\x64\x65\x66\x61ultMode\x12.\n\x07trigger\x18\x03 \x01(\x0e\x32\x14.vega.AuctionTriggerR\x07trigger\x12\x14\n\x05\x62\x65gin\x18\x04 \x01(\x03R\x05\x62\x65gin\x12\'\n\x03\x65nd\x18\x05 \x01(\x0b\x32\x15.vega.AuctionDurationR\x03\x65nd\x12\x14\n\x05start\x18\x06 \x01(\x08R\x05start\x12\x12\n\x04stop\x18\x07 \x01(\x08R\x04stop\x12\x32\n\textension\x18\x08 \x01(\x0e\x32\x14.vega.AuctionTriggerR\textension\x12\x30\n\x14\x65xtension_event_sent\x18\t \x01(\x08R\x12\x65xtensionEventSent"u\n\rEquityShareLP\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\x12\x14\n\x05stake\x18\x02 \x01(\tR\x05stake\x12\x14\n\x05share\x18\x03 \x01(\tR\x05share\x12\x10\n\x03\x61vg\x18\x04 \x01(\tR\x03\x61vg\x12\x16\n\x06vshare\x18\x05 \x01(\tR\x06vshare"\xa9\x01\n\x0b\x45quityShare\x12\x10\n\x03mvp\x18\x01 \x01(\tR\x03mvp\x12\x32\n\x15opening_auction_ended\x18\x02 \x01(\x08R\x13openingAuctionEnded\x12\x31\n\x03lps\x18\x03 \x03(\x0b\x32\x1f.vega.snapshot.v1.EquityShareLPR\x03lps\x12\x0c\n\x01r\x18\x04 \x01(\tR\x01r\x12\x13\n\x05p_mvp\x18\x05 \x01(\tR\x04pMvp"\x84\x01\n\x0b\x46\x65\x65Splitter\x12*\n\x11time_window_start\x18\x01 \x01(\x03R\x0ftimeWindowStart\x12\x1f\n\x0btrade_value\x18\x02 \x01(\tR\ntradeValue\x12\x10\n\x03\x61vg\x18\x03 \x01(\tR\x03\x61vg\x12\x16\n\x06window\x18\x04 \x01(\x04R\x06window"\xad\x07\n\x06Market\x12$\n\x06market\x18\x01 \x01(\x0b\x32\x0c.vega.MarketR\x06market\x12\x43\n\rprice_monitor\x18\x02 \x01(\x0b\x32\x1e.vega.snapshot.v1.PriceMonitorR\x0cpriceMonitor\x12\x43\n\rauction_state\x18\x03 \x01(\x0b\x32\x1e.vega.snapshot.v1.AuctionStateR\x0c\x61uctionState\x12\x43\n\rpegged_orders\x18\x04 \x01(\x0b\x32\x1e.vega.snapshot.v1.PeggedOrdersR\x0cpeggedOrders\x12\x34\n\x0f\x65xpiring_orders\x18\x05 \x03(\x0b\x32\x0b.vega.OrderR\x0e\x65xpiringOrders\x12"\n\rlast_best_bid\x18\x06 \x01(\tR\x0blastBestBid\x12"\n\rlast_best_ask\x18\x07 \x01(\tR\x0blastBestAsk\x12 \n\x0clast_mid_bid\x18\x08 \x01(\tR\nlastMidBid\x12 \n\x0clast_mid_ask\x18\t \x01(\tR\nlastMidAsk\x12\x35\n\x17last_market_value_proxy\x18\n \x01(\tR\x14lastMarketValueProxy\x12\x41\n\x1dlast_equity_share_distributed\x18\x0b \x01(\x03R\x1alastEquityShareDistributed\x12@\n\x0c\x65quity_share\x18\x0c \x01(\x0b\x32\x1d.vega.snapshot.v1.EquityShareR\x0b\x65quityShare\x12,\n\x12\x63urrent_mark_price\x18\r \x01(\tR\x10\x63urrentMarkPrice\x12*\n\x11risk_factor_short\x18\x0e \x01(\tR\x0friskFactorShort\x12(\n\x10risk_factor_long\x18\x0f \x01(\tR\x0eriskFactorLong\x12\x41\n\x1drisk_factor_consensus_reached\x18\x10 \x01(\x08R\x1ariskFactorConsensusReached\x12@\n\x0c\x66\x65\x65_splitter\x18\x11 \x01(\x0b\x32\x1d.vega.snapshot.v1.FeeSplitterR\x0b\x66\x65\x65Splitter\x12\'\n\x0fsettlement_data\x18\x12 \x01(\tR\x0esettlementData"@\n\x0cPeggedOrders\x12\x30\n\rparked_orders\x18\x02 \x03(\x0b\x32\x0b.vega.OrderR\x0cparkedOrders"F\n\x10\x45xecutionMarkets\x12\x32\n\x07markets\x18\x01 \x03(\x0b\x32\x18.vega.snapshot.v1.MarketR\x07markets"\xbb\x01\n\x08Position\x12\x19\n\x08party_id\x18\x01 \x01(\tR\x07partyId\x12\x12\n\x04size\x18\x02 \x01(\x03R\x04size\x12\x10\n\x03\x62uy\x18\x03 \x01(\x03R\x03\x62uy\x12\x12\n\x04sell\x18\x04 \x01(\x03R\x04sell\x12\x14\n\x05price\x18\x05 \x01(\tR\x05price\x12 \n\x0cvw_buy_price\x18\x06 \x01(\tR\nvwBuyPrice\x12"\n\rvw_sell_price\x18\x07 \x01(\tR\x0bvwSellPrice"h\n\x0fMarketPositions\x12\x1b\n\tmarket_id\x18\x01 \x01(\tR\x08marketId\x12\x38\n\tpositions\x18\x02 \x03(\x0b\x32\x1a.vega.snapshot.v1.PositionR\tpositions"g\n\x08\x41ppState\x12\x16\n\x06height\x18\x01 \x01(\x04R\x06height\x12\x14\n\x05\x62lock\x18\x02 \x01(\tR\x05\x62lock\x12\x12\n\x04time\x18\x03 \x01(\x03R\x04time\x12\x19\n\x08\x63hain_id\x18\x04 \x01(\tR\x07\x63hainId"\xc3\x01\n\nEpochState\x12\x10\n\x03seq\x18\x01 \x01(\x04R\x03seq\x12\x1d\n\nstart_time\x18\x03 \x01(\x03R\tstartTime\x12\x1f\n\x0b\x65xpire_time\x18\x04 \x01(\x03R\nexpireTime\x12\x36\n\x18ready_to_start_new_epoch\x18\x06 \x01(\x08R\x14readyToStartNewEpoch\x12+\n\x12ready_to_end_epoch\x18\x07 \x01(\x08R\x0freadyToEndEpoch"{\n\x15RewardsPendingPayouts\x12\x62\n\x18scheduled_rewards_payout\x18\x01 \x03(\x0b\x32(.vega.snapshot.v1.ScheduledRewardsPayoutR\x16scheduledRewardsPayout"\x81\x01\n\x16ScheduledRewardsPayout\x12\x1f\n\x0bpayout_time\x18\x01 \x01(\x03R\npayoutTime\x12\x46\n\x0erewards_payout\x18\x02 \x03(\x0b\x32\x1f.vega.snapshot.v1.RewardsPayoutR\rrewardsPayout"\xfc\x01\n\rRewardsPayout\x12!\n\x0c\x66rom_account\x18\x01 \x01(\tR\x0b\x66romAccount\x12\x14\n\x05\x61sset\x18\x02 \x01(\tR\x05\x61sset\x12T\n\x13reward_party_amount\x18\x03 \x03(\x0b\x32$.vega.snapshot.v1.RewardsPartyAmountR\x11rewardPartyAmount\x12!\n\x0ctotal_reward\x18\x04 \x01(\tR\x0btotalReward\x12\x1b\n\tepoch_seq\x18\x05 \x01(\tR\x08\x65pochSeq\x12\x1c\n\ttimestamp\x18\x06 \x01(\x03R\ttimestamp"B\n\x12RewardsPartyAmount\x12\x14\n\x05party\x18\x01 \x01(\tR\x05party\x12\x16\n\x06\x61mount\x18\x02 \x01(\tR\x06\x61mount"\x94\x03\n\nLimitState\x12\x1f\n\x0b\x62lock_count\x18\x01 \x01(\rR\nblockCount\x12,\n\x12\x63\x61n_propose_market\x18\x02 \x01(\x08R\x10\x63\x61nProposeMarket\x12*\n\x11\x63\x61n_propose_asset\x18\x03 \x01(\x08R\x0f\x63\x61nProposeAsset\x12%\n\x0egenesis_loaded\x18\x04 \x01(\x08R\rgenesisLoaded\x12\x34\n\x16propose_market_enabled\x18\x05 \x01(\x08R\x14proposeMarketEnabled\x12\x32\n\x15propose_asset_enabled\x18\x06 \x01(\x08R\x13proposeAssetEnabled\x12=\n\x1bpropose_market_enabled_from\x18\x07 \x01(\x03R\x18proposeMarketEnabledFrom\x12;\n\x1apropose_asset_enabled_from\x18\x08 \x01(\x03R\x17proposeAssetEnabledFrom"\x94\x04\n\x0eVoteSpamPolicy\x12L\n\rparty_to_vote\x18\x01 \x03(\x0b\x32(.vega.snapshot.v1.PartyProposalVoteCountR\x0bpartyToVote\x12\x44\n\x0e\x62\x61nned_parties\x18\x02 \x03(\x0b\x32\x1d.vega.snapshot.v1.BannedPartyR\rbannedParties\x12H\n\rtoken_balance\x18\x03 \x03(\x0b\x32#.vega.snapshot.v1.PartyTokenBalanceR\x0ctokenBalance\x12_\n\x1arecent_blocks_reject_stats\x18\x04 \x03(\x0b\x32".vega.snapshot.v1.BlockRejectStatsR\x17recentBlocksRejectStats\x12.\n\x13\x63urrent_block_index\x18\x05 \x01(\x04R\x11\x63urrentBlockIndex\x12.\n\x13last_increase_block\x18\x06 \x01(\x04R\x11lastIncreaseBlock\x12*\n\x11\x63urrent_epoch_seq\x18\x07 \x01(\x04R\x0f\x63urrentEpochSeq\x12\x37\n\x18min_voting_tokens_factor\x18\x08 \x01(\tR\x15minVotingTokensFactor"`\n\x16PartyProposalVoteCount\x12\x14\n\x05party\x18\x01 \x01(\tR\x05party\x12\x1a\n\x08proposal\x18\x02 \x01(\tR\x08proposal\x12\x14\n\x05\x63ount\x18\x03 \x01(\x04R\x05\x63ount"D\n\x0b\x42\x61nnedParty\x12\x14\n\x05party\x18\x01 \x01(\tR\x05party\x12\x1f\n\x0buntil_epoch\x18\x02 \x01(\x04R\nuntilEpoch"C\n\x11PartyTokenBalance\x12\x14\n\x05party\x18\x01 \x01(\tR\x05party\x12\x18\n\x07\x62\x61lance\x18\x02 \x01(\tR\x07\x62\x61lance"D\n\x10\x42lockRejectStats\x12\x1a\n\x08rejected\x18\x01 \x01(\x04R\x08rejected\x12\x14\n\x05total\x18\x02 \x01(\x04R\x05total"G\n\x19SpamPartyTransactionCount\x12\x14\n\x05party\x18\x01 \x01(\tR\x05party\x12\x14\n\x05\x63ount\x18\x02 \x01(\x04R\x05\x63ount"\xc2\x02\n\x10SimpleSpamPolicy\x12\x1f\n\x0bpolicy_name\x18\x01 \x01(\tR\npolicyName\x12Q\n\x0eparty_to_count\x18\x02 \x03(\x0b\x32+.vega.snapshot.v1.SpamPartyTransactionCountR\x0cpartyToCount\x12\x44\n\x0e\x62\x61nned_parties\x18\x03 \x03(\x0b\x32\x1d.vega.snapshot.v1.BannedPartyR\rbannedParties\x12H\n\rtoken_balance\x18\x04 \x03(\x0b\x32#.vega.snapshot.v1.PartyTokenBalanceR\x0ctokenBalance\x12*\n\x11\x63urrent_epoch_seq\x18\x05 \x01(\x04R\x0f\x63urrentEpochSeq"V\n\nNotarySigs\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\x12\x12\n\x04kind\x18\x02 \x01(\x05R\x04kind\x12\x12\n\x04node\x18\x03 \x01(\tR\x04node\x12\x10\n\x03sig\x18\x04 \x01(\tR\x03sig"G\n\x06Notary\x12=\n\x0bnotary_sigs\x18\x01 \x03(\x0b\x32\x1c.vega.snapshot.v1.NotarySigsR\nnotarySigs"m\n\x16StakeVerifierDeposited\x12S\n\x11pending_deposited\x18\x01 \x03(\x0b\x32&.vega.snapshot.v1.StakeVerifierPendingR\x10pendingDeposited"g\n\x14StakeVerifierRemoved\x12O\n\x0fpending_removed\x18\x01 \x03(\x0b\x32&.vega.snapshot.v1.StakeVerifierPendingR\x0ependingRemoved"\x85\x02\n\x14StakeVerifierPending\x12)\n\x10\x65thereum_address\x18\x01 \x01(\tR\x0f\x65thereumAddress\x12&\n\x0fvega_public_key\x18\x02 \x01(\tR\rvegaPublicKey\x12\x16\n\x06\x61mount\x18\x03 \x01(\tR\x06\x61mount\x12\x1d\n\nblock_time\x18\x04 \x01(\x03R\tblockTime\x12!\n\x0c\x62lock_number\x18\x05 \x01(\x04R\x0b\x62lockNumber\x12\x1b\n\tlog_index\x18\x06 \x01(\x04R\x08logIndex\x12\x13\n\x05tx_id\x18\x07 \x01(\tR\x04txId\x12\x0e\n\x02id\x18\x08 \x01(\tR\x02id"\x9b\x01\n\x12PendingKeyRotation\x12!\n\x0c\x62lock_height\x18\x01 \x01(\x04R\x0b\x62lockHeight\x12\x17\n\x07node_id\x18\x02 \x01(\tR\x06nodeId\x12\x1e\n\x0bnew_pub_key\x18\x03 \x01(\tR\tnewPubKey\x12)\n\x11new_pub_key_index\x18\x04 \x01(\rR\x0enewPubKeyIndex"\xb8\x01\n\x1aPendingEthereumKeyRotation\x12!\n\x0c\x62lock_height\x18\x01 \x01(\x04R\x0b\x62lockHeight\x12\x17\n\x07node_id\x18\x02 \x01(\tR\x06nodeId\x12\x1f\n\x0bnew_address\x18\x03 \x01(\tR\nnewAddress\x12\x1c\n\tsubmitter\x18\x04 \x01(\tR\tsubmitter\x12\x1f\n\x0bold_address\x18\x05 \x01(\tR\noldAddress"\xdd\x04\n\x08Topology\x12G\n\x0evalidator_data\x18\x01 \x03(\x0b\x32 .vega.snapshot.v1.ValidatorStateR\rvalidatorData\x12\x1d\n\nchain_keys\x18\x02 \x03(\tR\tchainKeys\x12_\n\x19pending_pub_key_rotations\x18\x03 \x03(\x0b\x32$.vega.snapshot.v1.PendingKeyRotationR\x16pendingPubKeyRotations\x12[\n\x15validator_performance\x18\x04 \x01(\x0b\x32&.vega.snapshot.v1.ValidatorPerformanceR\x14validatorPerformance\x12q\n\x1epending_ethereum_key_rotations\x18\x05 \x03(\x0b\x32,.vega.snapshot.v1.PendingEthereumKeyRotationR\x1bpendingEthereumKeyRotations\x12\x43\n\nsignatures\x18\x06 \x01(\x0b\x32#.vega.snapshot.v1.ToplogySignaturesR\nsignatures\x12s\n\x1funsolved_ethereum_key_rotations\x18\x07 \x03(\x0b\x32,.vega.snapshot.v1.PendingEthereumKeyRotationR\x1cunsolvedEthereumKeyRotations"\xa7\x01\n\x11ToplogySignatures\x12\x65\n\x12pending_signatures\x18\x01 \x03(\x0b\x32\x36.vega.snapshot.v1.PendingERC20MultisigControlSignatureR\x11pendingSignatures\x12+\n\x11issued_signatures\x18\x02 \x03(\tR\x10issuedSignatures"\xb3\x01\n$PendingERC20MultisigControlSignature\x12\x17\n\x07node_id\x18\x01 \x01(\tR\x06nodeId\x12)\n\x10\x65thereum_address\x18\x02 \x01(\tR\x0f\x65thereumAddress\x12\x14\n\x05nonce\x18\x03 \x01(\tR\x05nonce\x12\x1b\n\tepoch_seq\x18\x04 \x01(\x04R\x08\x65pochSeq\x12\x14\n\x05\x61\x64\x64\x65\x64\x18\x05 \x01(\x08R\x05\x61\x64\x64\x65\x64"\xf2\x03\n\x0eValidatorState\x12J\n\x10validator_update\x18\x01 \x01(\x0b\x32\x1f.vega.events.v1.ValidatorUpdateR\x0fvalidatorUpdate\x12\x1f\n\x0b\x62lock_added\x18\x02 \x01(\x04R\nblockAdded\x12\x16\n\x06status\x18\x03 \x01(\x05R\x06status\x12.\n\x13status_change_block\x18\x04 \x01(\x04R\x11statusChangeBlock\x12\x46\n last_block_with_positive_ranking\x18\x05 \x01(\x04R\x1clastBlockWithPositiveRanking\x12\x30\n\x14\x65th_events_forwarded\x18\x06 \x01(\x04R\x12\x65thEventsForwarded\x12O\n\x11heartbeat_tracker\x18\x07 \x01(\x0b\x32".vega.snapshot.v1.HeartbeatTrackerR\x10heartbeatTracker\x12\'\n\x0fvalidator_power\x18\x08 \x01(\x03R\x0evalidatorPower\x12\x37\n\rranking_score\x18\t \x01(\x0b\x32\x12.vega.RankingScoreR\x0crankingScore"\xb9\x01\n\x10HeartbeatTracker\x12,\n\x12\x65xpected_next_hash\x18\x01 \x01(\tR\x10\x65xpectedNextHash\x12\x37\n\x18\x65xpected_next_hash_since\x18\x02 \x01(\x03R\x15\x65xpectedNextHashSince\x12\x1f\n\x0b\x62lock_index\x18\x03 \x01(\x05R\nblockIndex\x12\x1d\n\nblock_sigs\x18\x04 \x03(\x08R\tblockSigs"\x99\x02\n\x10PerformanceStats\x12+\n\x11validator_address\x18\x01 \x01(\tR\x10validatorAddress\x12\x1a\n\x08proposed\x18\x02 \x01(\x04R\x08proposed\x12\x18\n\x07\x65lected\x18\x03 \x01(\x04R\x07\x65lected\x12\x14\n\x05voted\x18\x04 \x01(\x04R\x05voted\x12*\n\x11last_height_voted\x18\x05 \x01(\x03R\x0flastHeightVoted\x12\x30\n\x14last_height_proposed\x18\x06 \x01(\x03R\x12lastHeightProposed\x12.\n\x13last_height_elected\x18\x07 \x01(\x03R\x11lastHeightElected"l\n\x14ValidatorPerformance\x12T\n\x14validator_perf_stats\x18\x01 \x03(\x0b\x32".vega.snapshot.v1.PerformanceStatsR\x12validatorPerfStats"\xae\x01\n\x13LiquidityParameters\x12\x17\n\x07max_fee\x18\x01 \x01(\tR\x06maxFee\x12$\n\x0emax_shape_size\x18\x02 \x01(\tR\x0cmaxShapeSize\x12;\n\x1astake_to_obligation_factor\x18\x03 \x01(\tR\x17stakeToObligationFactor\x12\x1b\n\tmarket_id\x18\x04 \x01(\tR\x08marketId"h\n\x1aLiquidityPendingProvisions\x12-\n\x12pending_provisions\x18\x01 \x03(\tR\x11pendingProvisions\x12\x1b\n\tmarket_id\x18\x02 \x01(\tR\x08marketId"\x80\x01\n\x1fLiquidityPartiesLiquidityOrders\x12@\n\x0cparty_orders\x18\x01 \x03(\x0b\x32\x1d.vega.snapshot.v1.PartyOrdersR\x0bpartyOrders\x12\x1b\n\tmarket_id\x18\x02 \x01(\tR\x08marketId"H\n\x0bPartyOrders\x12\x14\n\x05party\x18\x01 \x01(\tR\x05party\x12#\n\x06orders\x18\x02 \x03(\x0b\x32\x0b.vega.OrderR\x06orders"w\n\x16LiquidityPartiesOrders\x12@\n\x0cparty_orders\x18\x01 \x03(\x0b\x32\x1d.vega.snapshot.v1.PartyOrdersR\x0bpartyOrders\x12\x1b\n\tmarket_id\x18\x02 \x01(\tR\x08marketId"\x7f\n\x13LiquidityProvisions\x12K\n\x14liquidity_provisions\x18\x01 \x03(\x0b\x32\x18.vega.LiquidityProvisionR\x13liquidityProvisions\x12\x1b\n\tmarket_id\x18\x02 \x01(\tR\x08marketId"\xb9\x01\n\x16\x46loatingPointConsensus\x12M\n\x11next_time_trigger\x18\x01 \x03(\x0b\x32!.vega.snapshot.v1.NextTimeTriggerR\x0fnextTimeTrigger\x12P\n\x0fstate_variables\x18\x02 \x03(\x0b\x32\'.vega.snapshot.v1.StateVarInternalStateR\x0estateVariables"\xfc\x01\n\x15StateVarInternalState\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\x12\x14\n\x05state\x18\x02 \x01(\x05R\x05state\x12\x19\n\x08\x65vent_id\x18\x03 \x01(\tR\x07\x65ventId\x12]\n\x12validators_results\x18\x04 \x03(\x0b\x32..vega.snapshot.v1.FloatingPointValidatorResultR\x11validatorsResults\x12\x43\n\x1erounds_since_meaningful_update\x18\x05 \x01(\x05R\x1broundsSinceMeaningfulUpdate"\\\n\x1c\x46loatingPointValidatorResult\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\x12,\n\x06\x62undle\x18\x02 \x03(\x0b\x32\x14.vega.KeyValueBundleR\x06\x62undle"r\n\x0fNextTimeTrigger\x12\x14\n\x05\x61sset\x18\x01 \x01(\tR\x05\x61sset\x12\x16\n\x06market\x18\x02 \x01(\tR\x06market\x12\x0e\n\x02id\x18\x03 \x01(\tR\x02id\x12!\n\x0cnext_trigger\x18\x04 \x01(\x03R\x0bnextTrigger"c\n\rMarketTracker\x12R\n\x0fmarket_activity\x18\x01 \x03(\x0b\x32).vega.checkpoint.v1.MarketActivityTrackerR\x0emarketActivity"t\n\x16SignerEventsPerAddress\x12\x18\n\x07\x61\x64\x64ress\x18\x01 \x01(\tR\x07\x61\x64\x64ress\x12@\n\x06\x65vents\x18\x02 \x03(\x0b\x32(.vega.events.v1.ERC20MultiSigSignerEventR\x06\x65vents"\x80\x02\n\x1d\x45RC20MultiSigTopologyVerified\x12\x18\n\x07signers\x18\x01 \x03(\tR\x07signers\x12V\n\x12\x65vents_per_address\x18\x02 \x03(\x0b\x32(.vega.snapshot.v1.SignerEventsPerAddressR\x10\x65ventsPerAddress\x12L\n\tthreshold\x18\x03 \x01(\x0b\x32..vega.events.v1.ERC20MultiSigThresholdSetEventR\tthreshold\x12\x1f\n\x0bseen_events\x18\x04 \x03(\tR\nseenEvents"\xbc\x02\n\x1c\x45RC20MultiSigTopologyPending\x12Q\n\x0fpending_signers\x18\x01 \x03(\x0b\x32(.vega.events.v1.ERC20MultiSigSignerEventR\x0ependingSigners\x12\x62\n\x15pending_threshold_set\x18\x02 \x03(\x0b\x32..vega.events.v1.ERC20MultiSigThresholdSetEventR\x13pendingThresholdSet\x12+\n\x11witnessed_signers\x18\x03 \x03(\tR\x10witnessedSigners\x12\x38\n\x18witnessed_threshold_sets\x18\x04 \x03(\tR\x16witnessedThresholdSets"\xe0\x02\n\x0bProofOfWork\x12!\n\x0c\x62lock_height\x18\x01 \x03(\x04R\x0b\x62lockHeight\x12\x1d\n\nblock_hash\x18\x02 \x03(\tR\tblockHash\x12H\n\x0ctx_at_height\x18\x04 \x03(\x0b\x32&.vega.snapshot.v1.TransactionsAtHeightR\ntxAtHeight\x12J\n\rtid_at_height\x18\x06 \x03(\x0b\x32&.vega.snapshot.v1.TransactionsAtHeightR\x0btidAtHeight\x12\x35\n\x06\x62\x61nned\x18\x07 \x03(\x0b\x32\x1d.vega.snapshot.v1.BannedPartyR\x06\x62\x61nned\x12\x42\n\npow_params\x18\x08 \x03(\x0b\x32#.vega.snapshot.v1.ProofOfWorkParamsR\tpowParams"\x84\x03\n\x11ProofOfWorkParams\x12\x41\n\x1espam_pow_number_of_past_blocks\x18\x01 \x01(\x04R\x19spamPowNumberOfPastBlocks\x12.\n\x13spam_pow_difficulty\x18\x02 \x01(\rR\x11spamPowDifficulty\x12\x33\n\x16spam_pow_hash_function\x18\x03 \x01(\tR\x13spamPowHashFunction\x12\x42\n\x1fspam_pow_number_of_tx_per_block\x18\x04 \x01(\x04R\x19spamPowNumberOfTxPerBlock\x12\x43\n\x1espam_pow_increasing_difficulty\x18\x05 \x01(\x08R\x1bspamPowIncreasingDifficulty\x12\x1d\n\nfrom_block\x18\x06 \x01(\x04R\tfromBlock\x12\x1f\n\x0buntil_block\x18\x07 \x01(\x03R\nuntilBlock"R\n\x14TransactionsAtHeight\x12\x16\n\x06height\x18\x01 \x01(\x04R\x06height\x12"\n\x0ctransactions\x18\x02 \x03(\tR\x0ctransactions"\xcb\x01\n\x18ProtocolUpgradeProposals\x12O\n\x10\x61\x63tive_proposals\x18\x01 \x03(\x0b\x32$.vega.events.v1.ProtocolUpgradeEventR\x0f\x61\x63tiveProposals\x12^\n\x11\x61\x63\x63\x65pted_proposal\x18\x02 \x01(\x0b\x32\x31.vega.snapshot.v1.AcceptedProtocolUpgradeProposalR\x10\x61\x63\x63\x65ptedProposal"}\n\x1f\x41\x63\x63\x65ptedProtocolUpgradeProposal\x12\x30\n\x14upgrade_block_height\x18\x01 \x01(\x04R\x12upgradeBlockHeight\x12(\n\x10vega_release_tag\x18\x02 \x01(\tR\x0evegaReleaseTag*`\n\x06\x46ormat\x12\x16\n\x12\x46ORMAT_UNSPECIFIED\x10\x00\x12\x10\n\x0c\x46ORMAT_PROTO\x10\x01\x12\x1b\n\x17\x46ORMAT_PROTO_COMPRESSED\x10\x02\x12\x0f\n\x0b\x46ORMAT_JSON\x10\x03\x42\x33Z1code.vegaprotocol.io/vega/protos/vega/snapshot/v1b\x06proto3'
)

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(
    DESCRIPTOR, "vega.snapshot.v1.snapshot_pb2", globals()
)
if _descriptor._USE_C_DESCRIPTORS == False:

    DESCRIPTOR._options = None
    DESCRIPTOR._serialized_options = (
        b"Z1code.vegaprotocol.io/vega/protos/vega/snapshot/v1"
    )
    _FORMAT._serialized_start = 21794
    _FORMAT._serialized_end = 21890
    _SNAPSHOT._serialized_start = 249
    _SNAPSHOT._serialized_end = 405
    _NODEHASH._serialized_start = 407
    _NODEHASH._serialized_end = 530
    _METADATA._serialized_start = 533
    _METADATA._serialized_end = 665
    _CHUNK._serialized_start = 667
    _CHUNK._serialized_end = 753
    _PAYLOAD._serialized_start = 756
    _PAYLOAD._serialized_end = 5151
    _TIMESTAMPEDOPENINTEREST._serialized_start = 5153
    _TIMESTAMPEDOPENINTEREST._serialized_end = 5235
    _LIQUIDITYTARGET._serialized_start = 5238
    _LIQUIDITYTARGET._serialized_end = 5608
    _LIQUIDITYPRICEPROBABILITYPAIR._serialized_start = 5610
    _LIQUIDITYPRICEPROBABILITYPAIR._serialized_end = 5697
    _LIQUIDITYSUPPLIED._serialized_start = 5700
    _LIQUIDITYSUPPLIED._serialized_end = 5949
    _ORACLEDATABATCH._serialized_start = 5951
    _ORACLEDATABATCH._serialized_end = 6031
    _ORACLEDATA._serialized_start = 6033
    _ORACLEDATA._serialized_end = 6147
    _ORACLEDATAPAIR._serialized_start = 6149
    _ORACLEDATAPAIR._serialized_end = 6205
    _WITNESS._serialized_start = 6207
    _WITNESS._serialized_end = 6274
    _RESOURCE._serialized_start = 6276
    _RESOURCE._serialized_end = 6379
    _EVENTFORWARDER._serialized_start = 6381
    _EVENTFORWARDER._serialized_end = 6432
    _COLLATERALACCOUNTS._serialized_start = 6434
    _COLLATERALACCOUNTS._serialized_end = 6497
    _COLLATERALASSETS._serialized_start = 6499
    _COLLATERALASSETS._serialized_end = 6554
    _ACTIVEASSETS._serialized_start = 6556
    _ACTIVEASSETS._serialized_end = 6607
    _PENDINGASSETS._serialized_start = 6609
    _PENDINGASSETS._serialized_end = 6661
    _PENDINGASSETUPDATES._serialized_start = 6663
    _PENDINGASSETUPDATES._serialized_end = 6721
    _WITHDRAWAL._serialized_start = 6723
    _WITHDRAWAL._serialized_end = 6803
    _DEPOSIT._serialized_start = 6805
    _DEPOSIT._serialized_end = 6871
    _TXREF._serialized_start = 6873
    _TXREF._serialized_end = 6978
    _ASSETACTION._serialized_start = 6981
    _ASSETACTION._serialized_end = 7506
    _BANKINGWITHDRAWALS._serialized_start = 7508
    _BANKINGWITHDRAWALS._serialized_end = 7592
    _BANKINGDEPOSITS._serialized_start = 7594
    _BANKINGDEPOSITS._serialized_end = 7664
    _BANKINGSEEN._serialized_start = 7666
    _BANKINGSEEN._serialized_end = 7699
    _BANKINGASSETACTIONS._serialized_start = 7701
    _BANKINGASSETACTIONS._serialized_end = 7788
    _BANKINGRECURRINGTRANSFERS._serialized_start = 7790
    _BANKINGRECURRINGTRANSFERS._serialized_end = 7906
    _BANKINGSCHEDULEDTRANSFERS._serialized_start = 7908
    _BANKINGSCHEDULEDTRANSFERS._serialized_end = 8024
    _BANKINGBRIDGESTATE._serialized_start = 8026
    _BANKINGBRIDGESTATE._serialized_end = 8114
    _CHECKPOINT._serialized_start = 8116
    _CHECKPOINT._serialized_end = 8153
    _DELEGATIONLASTRECONCILIATIONTIME._serialized_start = 8155
    _DELEGATIONLASTRECONCILIATIONTIME._serialized_end = 8247
    _DELEGATIONACTIVE._serialized_start = 8249
    _DELEGATIONACTIVE._serialized_end = 8319
    _DELEGATIONPENDING._serialized_start = 8321
    _DELEGATIONPENDING._serialized_end = 8446
    _DELEGATIONAUTO._serialized_start = 8448
    _DELEGATIONAUTO._serialized_end = 8490
    _PROPOSALDATA._serialized_start = 8493
    _PROPOSALDATA._serialized_end = 8647
    _GOVERNANCEENACTED._serialized_start = 8649
    _GOVERNANCEENACTED._serialized_end = 8730
    _GOVERNANCEACTIVE._serialized_start = 8732
    _GOVERNANCEACTIVE._serialized_end = 8812
    _GOVERNANCENODE._serialized_start = 8814
    _GOVERNANCENODE._serialized_end = 8876
    _STAKINGACCOUNT._serialized_start = 8878
    _STAKINGACCOUNT._serialized_end = 8996
    _STAKINGACCOUNTS._serialized_start = 8999
    _STAKINGACCOUNTS._serialized_end = 9139
    _MATCHINGBOOK._serialized_start = 9142
    _MATCHINGBOOK._serialized_end = 9346
    _NETPARAMS._serialized_start = 9348
    _NETPARAMS._serialized_end = 9407
    _DECIMALMAP._serialized_start = 9409
    _DECIMALMAP._serialized_end = 9457
    _TIMEPRICE._serialized_start = 9459
    _TIMEPRICE._serialized_end = 9512
    _PRICEVOLUME._serialized_start = 9514
    _PRICEVOLUME._serialized_end = 9573
    _PRICERANGE._serialized_start = 9575
    _PRICERANGE._serialized_end = 9641
    _PRICEBOUND._serialized_start = 9644
    _PRICEBOUND._serialized_end = 9798
    _PRICERANGECACHE._serialized_start = 9800
    _PRICERANGECACHE._serialized_end = 9921
    _CURRENTPRICE._serialized_start = 9923
    _CURRENTPRICE._serialized_end = 9983
    _PASTPRICE._serialized_start = 9985
    _PASTPRICE._serialized_end = 10068
    _PRICEMONITOR._serialized_start = 10071
    _PRICEMONITOR._serialized_end = 10699
    _AUCTIONSTATE._serialized_start = 10702
    _AUCTIONSTATE._serialized_end = 11078
    _EQUITYSHARELP._serialized_start = 11080
    _EQUITYSHARELP._serialized_end = 11197
    _EQUITYSHARE._serialized_start = 11200
    _EQUITYSHARE._serialized_end = 11369
    _FEESPLITTER._serialized_start = 11372
    _FEESPLITTER._serialized_end = 11504
    _MARKET._serialized_start = 11507
    _MARKET._serialized_end = 12448
    _PEGGEDORDERS._serialized_start = 12450
    _PEGGEDORDERS._serialized_end = 12514
    _EXECUTIONMARKETS._serialized_start = 12516
    _EXECUTIONMARKETS._serialized_end = 12586
    _POSITION._serialized_start = 12589
    _POSITION._serialized_end = 12776
    _MARKETPOSITIONS._serialized_start = 12778
    _MARKETPOSITIONS._serialized_end = 12882
    _APPSTATE._serialized_start = 12884
    _APPSTATE._serialized_end = 12987
    _EPOCHSTATE._serialized_start = 12990
    _EPOCHSTATE._serialized_end = 13185
    _REWARDSPENDINGPAYOUTS._serialized_start = 13187
    _REWARDSPENDINGPAYOUTS._serialized_end = 13310
    _SCHEDULEDREWARDSPAYOUT._serialized_start = 13313
    _SCHEDULEDREWARDSPAYOUT._serialized_end = 13442
    _REWARDSPAYOUT._serialized_start = 13445
    _REWARDSPAYOUT._serialized_end = 13697
    _REWARDSPARTYAMOUNT._serialized_start = 13699
    _REWARDSPARTYAMOUNT._serialized_end = 13765
    _LIMITSTATE._serialized_start = 13768
    _LIMITSTATE._serialized_end = 14172
    _VOTESPAMPOLICY._serialized_start = 14175
    _VOTESPAMPOLICY._serialized_end = 14707
    _PARTYPROPOSALVOTECOUNT._serialized_start = 14709
    _PARTYPROPOSALVOTECOUNT._serialized_end = 14805
    _BANNEDPARTY._serialized_start = 14807
    _BANNEDPARTY._serialized_end = 14875
    _PARTYTOKENBALANCE._serialized_start = 14877
    _PARTYTOKENBALANCE._serialized_end = 14944
    _BLOCKREJECTSTATS._serialized_start = 14946
    _BLOCKREJECTSTATS._serialized_end = 15014
    _SPAMPARTYTRANSACTIONCOUNT._serialized_start = 15016
    _SPAMPARTYTRANSACTIONCOUNT._serialized_end = 15087
    _SIMPLESPAMPOLICY._serialized_start = 15090
    _SIMPLESPAMPOLICY._serialized_end = 15412
    _NOTARYSIGS._serialized_start = 15414
    _NOTARYSIGS._serialized_end = 15500
    _NOTARY._serialized_start = 15502
    _NOTARY._serialized_end = 15573
    _STAKEVERIFIERDEPOSITED._serialized_start = 15575
    _STAKEVERIFIERDEPOSITED._serialized_end = 15684
    _STAKEVERIFIERREMOVED._serialized_start = 15686
    _STAKEVERIFIERREMOVED._serialized_end = 15789
    _STAKEVERIFIERPENDING._serialized_start = 15792
    _STAKEVERIFIERPENDING._serialized_end = 16053
    _PENDINGKEYROTATION._serialized_start = 16056
    _PENDINGKEYROTATION._serialized_end = 16211
    _PENDINGETHEREUMKEYROTATION._serialized_start = 16214
    _PENDINGETHEREUMKEYROTATION._serialized_end = 16398
    _TOPOLOGY._serialized_start = 16401
    _TOPOLOGY._serialized_end = 17006
    _TOPLOGYSIGNATURES._serialized_start = 17009
    _TOPLOGYSIGNATURES._serialized_end = 17176
    _PENDINGERC20MULTISIGCONTROLSIGNATURE._serialized_start = 17179
    _PENDINGERC20MULTISIGCONTROLSIGNATURE._serialized_end = 17358
    _VALIDATORSTATE._serialized_start = 17361
    _VALIDATORSTATE._serialized_end = 17859
    _HEARTBEATTRACKER._serialized_start = 17862
    _HEARTBEATTRACKER._serialized_end = 18047
    _PERFORMANCESTATS._serialized_start = 18050
    _PERFORMANCESTATS._serialized_end = 18331
    _VALIDATORPERFORMANCE._serialized_start = 18333
    _VALIDATORPERFORMANCE._serialized_end = 18441
    _LIQUIDITYPARAMETERS._serialized_start = 18444
    _LIQUIDITYPARAMETERS._serialized_end = 18618
    _LIQUIDITYPENDINGPROVISIONS._serialized_start = 18620
    _LIQUIDITYPENDINGPROVISIONS._serialized_end = 18724
    _LIQUIDITYPARTIESLIQUIDITYORDERS._serialized_start = 18727
    _LIQUIDITYPARTIESLIQUIDITYORDERS._serialized_end = 18855
    _PARTYORDERS._serialized_start = 18857
    _PARTYORDERS._serialized_end = 18929
    _LIQUIDITYPARTIESORDERS._serialized_start = 18931
    _LIQUIDITYPARTIESORDERS._serialized_end = 19050
    _LIQUIDITYPROVISIONS._serialized_start = 19052
    _LIQUIDITYPROVISIONS._serialized_end = 19179
    _FLOATINGPOINTCONSENSUS._serialized_start = 19182
    _FLOATINGPOINTCONSENSUS._serialized_end = 19367
    _STATEVARINTERNALSTATE._serialized_start = 19370
    _STATEVARINTERNALSTATE._serialized_end = 19622
    _FLOATINGPOINTVALIDATORRESULT._serialized_start = 19624
    _FLOATINGPOINTVALIDATORRESULT._serialized_end = 19716
    _NEXTTIMETRIGGER._serialized_start = 19718
    _NEXTTIMETRIGGER._serialized_end = 19832
    _MARKETTRACKER._serialized_start = 19834
    _MARKETTRACKER._serialized_end = 19933
    _SIGNEREVENTSPERADDRESS._serialized_start = 19935
    _SIGNEREVENTSPERADDRESS._serialized_end = 20051
    _ERC20MULTISIGTOPOLOGYVERIFIED._serialized_start = 20054
    _ERC20MULTISIGTOPOLOGYVERIFIED._serialized_end = 20310
    _ERC20MULTISIGTOPOLOGYPENDING._serialized_start = 20313
    _ERC20MULTISIGTOPOLOGYPENDING._serialized_end = 20629
    _PROOFOFWORK._serialized_start = 20632
    _PROOFOFWORK._serialized_end = 20984
    _PROOFOFWORKPARAMS._serialized_start = 20987
    _PROOFOFWORKPARAMS._serialized_end = 21375
    _TRANSACTIONSATHEIGHT._serialized_start = 21377
    _TRANSACTIONSATHEIGHT._serialized_end = 21459
    _PROTOCOLUPGRADEPROPOSALS._serialized_start = 21462
    _PROTOCOLUPGRADEPROPOSALS._serialized_end = 21665
    _ACCEPTEDPROTOCOLUPGRADEPROPOSAL._serialized_start = 21667
    _ACCEPTEDPROTOCOLUPGRADEPROPOSAL._serialized_end = 21792
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: vega/commands/v1/validator_commands.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database

# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ... import vega_pb2 as vega_dot_vega__pb2
from ... import chain_events_pb2 as vega_dot_chain__events__pb2
from ...commands.v1 import signature_pb2 as vega_dot_commands_dot_v1_dot_signature__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n)vega/commands/v1/validator_commands.proto\x12\x10vega.commands.v1\x1a\x0fvega/vega.proto\x1a\x17vega/chain_events.proto\x1a vega/commands/v1/signature.proto"\xbd\x01\n\x12ValidatorHeartbeat\x12\x17\n\x07node_id\x18\x01 \x01(\tR\x06nodeId\x12J\n\x12\x65thereum_signature\x18\x02 \x01(\x0b\x32\x1b.vega.commands.v1.SignatureR\x11\x65thereumSignature\x12\x42\n\x0evega_signature\x18\x03 \x01(\x0b\x32\x1b.vega.commands.v1.SignatureR\rvegaSignature"\x80\x04\n\x0c\x41nnounceNode\x12 \n\x0cvega_pub_key\x18\x01 \x01(\tR\nvegaPubKey\x12)\n\x10\x65thereum_address\x18\x02 \x01(\tR\x0f\x65thereumAddress\x12"\n\rchain_pub_key\x18\x03 \x01(\tR\x0b\x63hainPubKey\x12\x19\n\x08info_url\x18\x04 \x01(\tR\x07infoUrl\x12\x18\n\x07\x63ountry\x18\x05 \x01(\tR\x07\x63ountry\x12\x0e\n\x02id\x18\x06 \x01(\tR\x02id\x12\x12\n\x04name\x18\x07 \x01(\tR\x04name\x12\x1d\n\navatar_url\x18\x08 \x01(\tR\tavatarUrl\x12+\n\x12vega_pub_key_index\x18\t \x01(\rR\x0fvegaPubKeyIndex\x12\x1d\n\nfrom_epoch\x18\n \x01(\x04R\tfromEpoch\x12J\n\x12\x65thereum_signature\x18\x0b \x01(\x0b\x32\x1b.vega.commands.v1.SignatureR\x11\x65thereumSignature\x12\x42\n\x0evega_signature\x18\x0c \x01(\x0b\x32\x1b.vega.commands.v1.SignatureR\rvegaSignature\x12+\n\x11submitter_address\x18\r \x01(\tR\x10submitterAddress".\n\x08NodeVote\x12\x1c\n\treference\x18\x02 \x01(\tR\treferenceJ\x04\x08\x01\x10\x02"j\n\rNodeSignature\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\x12\x10\n\x03sig\x18\x02 \x01(\x0cR\x03sig\x12\x37\n\x04kind\x18\x03 \x01(\x0e\x32#.vega.commands.v1.NodeSignatureKindR\x04kind"\xb1\x02\n\nChainEvent\x12\x13\n\x05tx_id\x18\x01 \x01(\tR\x04txId\x12\x14\n\x05nonce\x18\x02 \x01(\x04R\x05nonce\x12\x34\n\x07\x62uiltin\x18\xe9\x07 \x01(\x0b\x32\x17.vega.BuiltinAssetEventH\x00R\x07\x62uiltin\x12)\n\x05\x65rc20\x18\xea\x07 \x01(\x0b\x32\x10.vega.ERC20EventH\x00R\x05\x65rc20\x12:\n\rstaking_event\x18\xed\x07 \x01(\x0b\x32\x12.vega.StakingEventH\x00R\x0cstakingEvent\x12\x42\n\x0e\x65rc20_multisig\x18\xee\x07 \x01(\x0b\x32\x18.vega.ERC20MultiSigEventH\x00R\rerc20MultisigB\x07\n\x05\x65ventJ\x06\x08\xeb\x07\x10\xec\x07J\x06\x08\xec\x07\x10\xed\x07"\xb4\x01\n\x13KeyRotateSubmission\x12)\n\x11new_pub_key_index\x18\x01 \x01(\rR\x0enewPubKeyIndex\x12!\n\x0ctarget_block\x18\x02 \x01(\x04R\x0btargetBlock\x12\x1e\n\x0bnew_pub_key\x18\x03 \x01(\tR\tnewPubKey\x12/\n\x14\x63urrent_pub_key_hash\x18\x04 \x01(\tR\x11\x63urrentPubKeyHash"\x83\x02\n\x1b\x45thereumKeyRotateSubmission\x12!\n\x0ctarget_block\x18\x01 \x01(\x04R\x0btargetBlock\x12\x1f\n\x0bnew_address\x18\x02 \x01(\tR\nnewAddress\x12\'\n\x0f\x63urrent_address\x18\x03 \x01(\tR\x0e\x63urrentAddress\x12+\n\x11submitter_address\x18\x04 \x01(\tR\x10submitterAddress\x12J\n\x12\x65thereum_signature\x18\x05 \x01(\x0b\x32\x1b.vega.commands.v1.SignatureR\x11\x65thereumSignature"M\n\x15StateVariableProposal\x12\x34\n\x08proposal\x18\x01 \x01(\x0b\x32\x18.vega.StateValueProposalR\x08proposal"u\n\x17ProtocolUpgradeProposal\x12\x30\n\x14upgrade_block_height\x18\x01 \x01(\x04R\x12upgradeBlockHeight\x12(\n\x10vega_release_tag\x18\x02 \x01(\tR\x0evegaReleaseTag"\x94\x01\n\x0fIssueSignatures\x12\x1c\n\tsubmitter\x18\x01 \x01(\tR\tsubmitter\x12\x37\n\x04kind\x18\x02 \x01(\x0e\x32#.vega.commands.v1.NodeSignatureKindR\x04kind\x12*\n\x11validator_node_id\x18\x03 \x01(\tR\x0fvalidatorNodeId*\x97\x02\n\x11NodeSignatureKind\x12#\n\x1fNODE_SIGNATURE_KIND_UNSPECIFIED\x10\x00\x12!\n\x1dNODE_SIGNATURE_KIND_ASSET_NEW\x10\x01\x12(\n$NODE_SIGNATURE_KIND_ASSET_WITHDRAWAL\x10\x02\x12\x33\n/NODE_SIGNATURE_KIND_ERC20_MULTISIG_SIGNER_ADDED\x10\x03\x12\x35\n1NODE_SIGNATURE_KIND_ERC20_MULTISIG_SIGNER_REMOVED\x10\x04\x12$\n NODE_SIGNATURE_KIND_ASSET_UPDATE\x10\x05\x42\x33Z1code.vegaprotocol.io/vega/protos/vega/commands/v1b\x06proto3'
)

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(
    DESCRIPTOR, "vega.commands.v1.validator_commands_pb2", globals()
)
if _descriptor._USE_C_DESCRIPTORS == False:

    DESCRIPTOR._options = None
    DESCRIPTOR._serialized_options = (
        b"Z1code.vegaprotocol.io/vega/protos/vega/commands/v1"
    )
    _NODESIGNATUREKIND._serialized_start = 2105
    _NODESIGNATUREKIND._serialized_end = 2384
    _VALIDATORHEARTBEAT._serialized_start = 140
    _VALIDATORHEARTBEAT._serialized_end = 329
    _ANNOUNCENODE._serialized_start = 332
    _ANNOUNCENODE._serialized_end = 844
    _NODEVOTE._serialized_start = 846
    _NODEVOTE._serialized_end = 892
    _NODESIGNATURE._serialized_start = 894
    _NODESIGNATURE._serialized_end = 1000
    _CHAINEVENT._serialized_start = 1003
    _CHAINEVENT._serialized_end = 1308
    _KEYROTATESUBMISSION._serialized_start = 1311
    _KEYROTATESUBMISSION._serialized_end = 1491
    _ETHEREUMKEYROTATESUBMISSION._serialized_start = 1494
    _ETHEREUMKEYROTATESUBMISSION._serialized_end = 1753
    _STATEVARIABLEPROPOSAL._serialized_start = 1755
    _STATEVARIABLEPROPOSAL._serialized_end = 1832
    _PROTOCOLUPGRADEPROPOSAL._serialized_start = 1834
    _PROTOCOLUPGRADEPROPOSAL._serialized_end = 1951
    _ISSUESIGNATURES._serialized_start = 1954
    _ISSUESIGNATURES._serialized_end = 2102
# @@protoc_insertion_point(module_scope)



import argparse
import logging
import numpy as np
from typing import Any, Callable, List, Optional
from vega_sim.environment.agent import Agent

from vega_sim.scenario.scenario import Scenario
from vega_sim.scenario.common.utils.price_process import random_walk
from vega_sim.scenario.ideal_market_maker.environments import MarketEnvironment
from vega_sim.null_service import VegaServiceNull
from vega_sim.scenario.constants import Network
from vega_sim.scenario.ideal_market_maker.agents import (
    MM_WALLET,
    TERMINATE_WALLET,
    TRADER_WALLET,
    RANDOM_WALLET,
    AUCTION1_WALLET,
    AUCTION2_WALLET,
    INFORMED_WALLET,
    LIQUIDITY,
    OptimalLiquidityProvider,
    OptimalMarketMaker,
    MarketOrderTrader,
    LimitOrderTrader,
    OpenAuctionPass,
    InformedTrader,
)


class IdealMarketMaker(Scenario):
    def __init__(
        self,
        num_steps: int = 120,
        market_decimal: int = 5,
        asset_decimal: int = 5,
        market_position_decimal: int = 0,
        market_name: str = "ETH:USD",
        asset_name: str = "tDAI",
        initial_asset_mint: float = 1e6,
        lp_initial_mint: float = 1e6,
        lp_commitamount: float = 20000,
        initial_price: float = 0.3,
        sigma: float = 1,
        kappa: float = 500,
        lambda_val: float = 5,
        q_upper: int = 20,
        q_lower: int = -20,
        alpha: float = 10**-4,
        phi: float = 5 * 10**-6,
        spread: float = 0.00002,
        block_size: int = 1,
        block_length_seconds: int = 1,
        state_extraction_freq: int = 1,
        step_length_seconds: Optional[int] = None,
        state_extraction_fn: Optional[
            Callable[[VegaServiceNull, List[Agent]], Any]
        ] = None,
        proportion_taken: float = 0.8,
        price_process_fn: Optional[Callable] = None,
    ):
        self.num_steps = num_steps
        self.market_name = market_name
        self.asset_name = asset_name
        self.market_decimal = market_decimal
        self.asset_decimal = asset_decimal
        self.market_position_decimal = market_position_decimal
        self.lp_commitamount = lp_commitamount
        self.initial_asset_mint = initial_asset_mint
        self.lp_initial_mint = lp_initial_mint
        self.initial_price = initial_price
        self.sigma = sigma
        self.kappa = kappa
        self.lambda_val = lambda_val
        self.q_upper = q_upper
        self.q_lower = q_lower
        self.alpha = alpha
        self.phi = phi
        self.spread = spread
        self.block_size = block_size
        self.block_length_seconds = block_length_seconds
        self.state_extraction_freq = state_extraction_freq
        self.step_length_seconds = step_length_seconds
        self.state_extraction_fn = state_extraction_fn
        self.proportion_taken = proportion_taken
        self.price_process_fn = price_process_fn

    def _generate_price_process(
        self,
        random_state: Optional[np.random.RandomState] = None,
    ):
        return random_walk(
            num_steps=self.num_steps,
            sigma=self.sigma,
            starting_price=self.initial_price,
            random_state=random_state,
        )

    def set_up_background_market(
        self,
        vega: VegaServiceNull,
        tag: str = "",
        random_state: Optional[np.random.RandomState] = None,
    ) -> MarketEnvironment:

        market_name = self.market_name + f"_{tag}" if tag else self.market_name
        asset_name = self.asset_name + f"_{tag}" if tag else self.asset_name

        price_process = (
            self.price_process_fn()
            if self.price_process_fn is not None
            else self._generate_price_process(random_state=random_state)
        )

        market_maker = OptimalMarketMaker(
            wallet_name=MM_WALLET.name,
            wallet_pass=MM_WALLET.passphrase,
            terminate_wallet_name=TERMINATE_WALLET.name,
            terminate_wallet_pass=TERMINATE_WALLET.passphrase,
            price_process=price_process,
            spread=self.spread,
            num_steps=self.num_steps,
            market_order_arrival_rate=self.lambda_val,
            pegged_order_fill_rate=self.kappa,
            inventory_upper_boundary=self.q_upper,
            inventory_lower_boundary=self.q_lower,
            terminal_penalty_parameter=self.alpha,
            running_penalty_parameter=self.phi,
            asset_decimal=self.asset_decimal,
            initial_asset_mint=self.lp_initial_mint,
            market_decimal=self.market_decimal,
            market_position_decimal=self.market_position_decimal,
            market_name=market_name,
            asset_name=asset_name,
            commitamount=self.lp_commitamount,
            random_state=random_state,
            tag=str(tag),
        )

        tradingbot = MarketOrderTrader(
            wallet_name=TRADER_WALLET.name,
            wallet_pass=TRADER_WALLET.passphrase,
            market_name=market_name,
            asset_name=asset_name,
            initial_asset_mint=self.initial_asset_mint,
            tag=str(tag),
        )

        randomtrader = LimitOrderTrader(
            wallet_name=RANDOM_WALLET.name,
            wallet_pass=RANDOM_WALLET.passphrase,
            price_process=price_process,
            spread=self.spread,
            initial_price=self.initial_price,
            asset_decimal=self.asset_decimal,
            market_decimal=self.market_decimal,
            market_name=market_name,
            asset_name=asset_name,
            initial_asset_mint=self.initial_asset_mint,
            tag=str(tag),
        )

        auctionpass1 = OpenAuctionPass(
            wallet_name=AUCTION1_WALLET.name,
            wallet_pass=AUCTION1_WALLET.passphrase,
            side="SIDE_BUY",
            initial_price=self.initial_price,
            market_name=market_name,
            asset_name=asset_name,
            initial_asset_mint=self.initial_asset_mint,
            tag=str(tag),
        )

        auctionpass2 = OpenAuctionPass(
            wallet_name=AUCTION2_WALLET.name,
            wallet_pass=AUCTION2_WALLET.passphrase,
            side="SIDE_SELL",
            initial_price=self.initial_price,
            market_name=market_name,
            asset_name=asset_name,
            initial_asset_mint=self.initial_asset_mint,
            tag=str(tag),
        )

        liquidityprovider = OptimalLiquidityProvider(
            wallet_name=LIQUIDITY.name,
            wallet_pass=LIQUIDITY.passphrase,
            num_steps=self.num_steps,
            market_order_arrival_rate=self.lambda_val,
            pegged_order_fill_rate=self.kappa,
            inventory_upper_boundary=self.q_upper,
            inventory_lower_boundary=self.q_lower,
            terminal_penalty_parameter=self.alpha,
            running_penalty_parameter=self.phi,
            initial_asset_mint=self.initial_asset_mint,
            market_name=market_name,
            asset_name=asset_name,
            entry_step=5,
            commitamount=self.lp_commitamount,
        )

        info_trader = InformedTrader(
            wallet_name=INFORMED_WALLET.name,
            wallet_pass=INFORMED_WALLET.passphrase,
            price_process=price_process,
            market_name=market_name,
            asset_name=asset_name,
            initial_asset_mint=self.initial_asset_mint,
            proportion_taken=self.proportion_taken,
            tag=str(tag),
        )

        env = MarketEnvironment(
            base_agents=[
                market_maker,
                tradingbot,
                randomtrader,
                auctionpass1,
                auctionpass2,
                info_trader,
                liquidityprovider,
            ],
            n_steps=self.num_steps,
            transactions_per_block=self.block_size,
            vega_service=vega,
            state_extraction_freq=self.state_extraction_freq,
            step_length_seconds=self.step_length_seconds,
            block_length_seconds=self.block_length_seconds,
            state_extraction_fn=self.state_extraction_fn,
        )
        return env

    def run_iteration(
        self,
        vega: VegaServiceNull,
        network: Optional[Network] = None,
        pause_at_completion: bool = False,
        random_state: Optional[np.random.RandomState] = None,
    ):
        env = self.set_up_background_market(
            vega=vega, tag=str(0), random_state=random_state
        )
        result = env.run(
            pause_at_completion=pause_at_completion,
        )
        return result


if __name__ == "__main__":
    parser = argparse.ArgumentParser()
    parser.add_argument("--debug", action="store_true")
    args = parser.parse_args()

    logging.basicConfig(level=logging.INFO if not args.debug else logging.DEBUG)

    step_length = 60 * 60

    scenario = IdealMarketMaker(num_steps=100)

    with VegaServiceNull(
        warn_on_raw_data_access=False,
        run_with_console=True,
        seconds_per_block=40,  # Heuristic
    ) as vega:
        scenario.run_iteration(vega=vega, pause_at_completion=True)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: vega/data_source.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database

# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from .data.v1 import spec_pb2 as vega_dot_data_dot_v1_dot_spec__pb2
from .data.v1 import data_pb2 as vega_dot_data_dot_v1_dot_data__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n\x16vega/data_source.proto\x12\x04vega\x1a\x17vega/data/v1/spec.proto\x1a\x17vega/data/v1/data.proto"\xa9\x01\n\x14\x44\x61taSourceDefinition\x12@\n\x08internal\x18\x01 \x01(\x0b\x32".vega.DataSourceDefinitionInternalH\x00R\x08internal\x12@\n\x08\x65xternal\x18\x02 \x01(\x0b\x32".vega.DataSourceDefinitionExternalH\x00R\x08\x65xternalB\r\n\x0bsource_type"Z\n\x1f\x44\x61taSourceSpecConfigurationTime\x12\x37\n\nconditions\x18\x01 \x03(\x0b\x32\x17.vega.data.v1.ConditionR\nconditions"j\n\x1c\x44\x61taSourceDefinitionInternal\x12;\n\x04time\x18\x01 \x01(\x0b\x32%.vega.DataSourceSpecConfigurationTimeH\x00R\x04timeB\r\n\x0bsource_type"j\n\x1c\x44\x61taSourceDefinitionExternal\x12;\n\x06oracle\x18\x01 \x01(\x0b\x32!.vega.DataSourceSpecConfigurationH\x00R\x06oracleB\r\n\x0bsource_type"}\n\x1b\x44\x61taSourceSpecConfiguration\x12.\n\x07signers\x18\x01 \x03(\x0b\x32\x14.vega.data.v1.SignerR\x07signers\x12.\n\x07\x66ilters\x18\x02 \x03(\x0b\x32\x14.vega.data.v1.FilterR\x07\x66ilters"\x90\x02\n\x0e\x44\x61taSourceSpec\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\x12\x1d\n\ncreated_at\x18\x02 \x01(\x03R\tcreatedAt\x12\x1d\n\nupdated_at\x18\x03 \x01(\x03R\tupdatedAt\x12.\n\x04\x64\x61ta\x18\x04 \x01(\x0b\x32\x1a.vega.DataSourceDefinitionR\x04\x64\x61ta\x12\x33\n\x06status\x18\x05 \x01(\x0e\x32\x1b.vega.DataSourceSpec.StatusR\x06status"K\n\x06Status\x12\x16\n\x12STATUS_UNSPECIFIED\x10\x00\x12\x11\n\rSTATUS_ACTIVE\x10\x01\x12\x16\n\x12STATUS_DEACTIVATED\x10\x02"B\n\x16\x45xternalDataSourceSpec\x12(\n\x04spec\x18\x01 \x01(\x0b\x32\x14.vega.DataSourceSpecR\x04specB\'Z%code.vegaprotocol.io/vega/protos/vegab\x06proto3'
)

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, "vega.data_source_pb2", globals())
if _descriptor._USE_C_DESCRIPTORS == False:

    DESCRIPTOR._options = None
    DESCRIPTOR._serialized_options = b"Z%code.vegaprotocol.io/vega/protos/vega"
    _DATASOURCEDEFINITION._serialized_start = 83
    _DATASOURCEDEFINITION._serialized_end = 252
    _DATASOURCESPECCONFIGURATIONTIME._serialized_start = 254
    _DATASOURCESPECCONFIGURATIONTIME._serialized_end = 344
    _DATASOURCEDEFINITIONINTERNAL._serialized_start = 346
    _DATASOURCEDEFINITIONINTERNAL._serialized_end = 452
    _DATASOURCEDEFINITIONEXTERNAL._serialized_start = 454
    _DATASOURCEDEFINITIONEXTERNAL._serialized_end = 560
    _DATASOURCESPECCONFIGURATION._serialized_start = 562
    _DATASOURCESPECCONFIGURATION._serialized_end = 687
    _DATASOURCESPEC._serialized_start = 690
    _DATASOURCESPEC._serialized_end = 962
    _DATASOURCESPEC_STATUS._serialized_start = 887
    _DATASOURCESPEC_STATUS._serialized_end = 962
    _EXTERNALDATASOURCESPEC._serialized_start = 964
    _EXTERNALDATASOURCESPEC._serialized_end = 1030
# @@protoc_insertion_point(module_scope)
